Learn R Programming

iimi (version 1.2.2)

convert_rle_to_df: Convert run-length encodings (RLEs) to a data frame.

Description

Converts a list of run-length encodings (RLEs) into a data frame with 16 features after mappability profiling and nucleotide filtering.

Usage

convert_rle_to_df(
  covs,
  unreliable_region_version = "1_4_0",
  unreliable_region_enabled = TRUE,
  additional_nucleotide_info = data.frame()
)

Value

A data frame object that contains the mapping result for each virus segment that the plant sample reads are aligned to and a RLE list of coverage information.

Arguments

covs

A list of Coverage profile(s) in RLE format. Can be one or more samples.

unreliable_region_version

The version number (character string) of unreliable regions of the virus segments. Default is 1_4_0. It includes the mappability profile from a host genome (we only have Arabidopsis thaliana right now) and virus references, and the regions that have CG% and A% over 60% and 45% respectively.

unreliable_region_enabled

Default is TRUE. If TRUE, the input will be checked against unreliable_region_df. If FALSE, this step will be skipped.

additional_nucleotide_info

Additional nucleotide information for virus segments that are not included in nucleotide_info. The information provided must be a data frame that follows the format of nucleotide_info. Default is an empty data frame.

Details

Converts a list of run-length encodings (RLEs) into a data frame.

The returned dataframe contains 16 features for training a machine learning model. after mappability profiling and nucleotide filtering.

Examples

Run this code
if (FALSE) {
df <- convert_rle_to_df(example_cov)
}

Run the code above in your browser using DataLab