A data frame of unmappable regions and regions of CG% and A% over 60% and 45% respectively for the virus segments. It is worth to note that if a virus segment does not have any unreliable regions, that virus segment is not shown in this data frame.
unreliable_regionsA data frame of unreliable regions in the run-length encoding format for virus segments.
The start position of the region that is considered unreliable
The end position of the region that is considered unreliable
The virus segment ID
The category that this unrelible region belong to, which are Unmappable regions (host), Unmappable regions (virus), CG% > 60%, A% > 45%
The version number of the virus database
The version number of the virus database